<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 09/05/2008 *
 * ===================                          Last change: 09/05/2008 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : surfbar.php                                      *
 * -------------------------------------------------------------------- *
 * Short description : The surfbar itself                               *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Die Surfbar selbst                               *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Load security stuff here
require('inc/libs/security_functions.php');

// Init start time
$GLOBALS['startTime'] = microtime(true);

// Set module output mode
$GLOBALS['module'] = 'surfbar';
$GLOBALS['output_mode'] = '0';
$GLOBALS['header_sent'] = 3;

// Load the required file(s)
require('inc/config-global.php');

// Set content type
setContentType('text/html');

// Is a frame active?
if (isGetRequestElementSet('frame')) {
	// Then we need to set header_sent to 0
	$GLOBALS['header_sent'] = '0';
} // END - if

// Only logged in users may use this surfbar!
redirectOnUninstalledExtension('surfbar');

// No member?
if (!isMember()) {
	// Should we display login window or redirect to main page?
	if ((getConfig('surfbar_guest_login_form') == 'Y') && (isExtensionActive('user'))) {
		// Is the form sent?
		if ((isFormSent()) && (isPostRequestElementSet('id')) && (isPostRequestElementSet('password'))) {
			// Do the login procedure
			$url = doUserLogin(postRequestElement('id'), postRequestElement('password'), basename(__FILE__), basename(__FILE__) . '?code=');

			// And redirect to the URL
			redirectToUrl($url);
		} else {
			// Load header
			loadIncludeOnce('inc/header.php');

			// Is there a 'code' provided?
			if (isGetRequestElementSet('code')) {
				// Then generate an error message
				displayMessage(getMessageFromErrorCode(getRequestElement('code')));
			} // END - if

			// Display login form
			loadTemplate('surfbar_login_form');

			// Allow footer here
			$GLOBALS['header_sent'] = 2;

			// Load footer
			loadIncludeOnce('inc/footer.php');
		}
	} else {
		// Redirect
		redirectToUrl('modules.php?module=index');
	}
} // END - if

// Initialize the surfbar
SURFBAR_INIT();

// Handle tasks on self-maintenance
SURFBAR_HANDLE_SELF_MAINTENANCE();

// Is there a check value?
if ((SURFBAR_CHECK_RELOAD_FULL()) || ((isGetRequestElementSet('frame')) && (in_array(getRequestElement('frame'), array('stop', 'stop2', 'stats', 'textlinks'))))) {
	// Reload-lock is full, surfbar stopped so...
	// Load header
	loadIncludeOnce('inc/header.php');

	// Load template
	if (((isGetRequestElementSet('frame')) && (getRequestElement('frame') == 'stop2')) || (!isGetRequestElementSet('frame'))) {
		// Load template for "start" page
		loadTemplate('surfbar_frame_start');

		// Load banner
		loadTemplate('surfbar_start_banner');

		// This makes the footer appear again
		unsetGetRequestElement('frame');
	} elseif ((isGetRequestElementSet('frame')) && (getRequestElement('frame') == 'stats')) {
		// Prepare content
		$content = array(
			'points' => getTotalPoints(getMemberId()),
			'reload' => (getConfig('surfbar_stats_reload') * 1000)
		);

		// Load template for "stats" page
		loadTemplate('surfbar_frame_stats', false, $content);
	} elseif ((isGetRequestElementSet('frame')) && (getRequestElement('frame') == 'textlinks')) {
		// Prepare content
		$content = array(
			'reload' => (getConfig('surfbar_stats_reload') * 1000)
		);

		// Load template for "stats" page
		loadTemplate('surfbar_frame_textlinks', false, $content);
	} else {
		// Prepare content
		$content = array(
			'start'     => str_repeat('X', strlen(getConfig('surfbar_restart_time'))),
			'autostart' => (getConfig('surfbar_autostart') == 'Y') ? 'true' : 'false'
		);

		// Load template for stopped surfbar
		loadTemplate('surfbar_stopped', false, $content);
	}
} elseif ((isGetRequestElementSet('check')) && (isGetRequestElementSet('id')) && (isGetRequestElementSet('salt'))) {
	// Dummy next id get
	SURFBAR_DETERMINE_NEXT_ID(getRequestElement('id'));

	// Check reload lock and validation code
	if ((!SURFBAR_CHECK_RELOAD_LOCK(getRequestElement('id'))) && (SURFBAR_CHECK_VALIDATION_CODE(getRequestElement('id'), getRequestElement('check'), getRequestElement('salt')))) {
		// Lock the URL (id) down
		SURFBAR_LOCKDOWN_ID(getRequestElement('id'));

		// Code is valid so pay points here
		SURFBAR_PAY_POINTS();

		// Check if reload is full
		if (SURFBAR_CHECK_RELOAD_FULL()) {
			// Then load waiting page
			SURFBAR_RELOAD_TO_STOP_PAGE();
		} // END - if

		// Load header to avoid a bug
		loadIncludeOnce('inc/header.php');
	} else {
		// Reload to stop frame!
		SURFBAR_RELOAD_TO_STOP_PAGE();
	}

	// All done, so fix notice for footer.php
	$GLOBALS['footer_sent'] = 1;
} else {
	// Prepare content
	$content = '';

	// Frame "top" set?
	if ((isGetRequestElementSet('frame')) && (getRequestElement('frame') == 'top')) {
		// Determine next id
		$nextId = SURFBAR_DETERMINE_NEXT_ID();
		//* DEBUG: */ die('nextId='.$nextId);

		// Is there a valid id?
		if ($nextId > 0) {
			// Then prepare other content
			$content = array(
				'url_id' => $nextId,
				'xxx'    => str_repeat('X', strlen(SURFBAR_GET_RELOAD_TIME($nextId))),
			);

			// Update salt (double-call lock!) and statistics
			SURFBAR_UPDATE_SALT_STATS();
		} else {
			// Load new URL
			SURFBAR_RELOAD_TO_STOP_PAGE('stop');
		}
	} elseif ((isGetRequestElementSet('frame')) && (getRequestElement('frame') == 'start')) {
		// Starter frame found so let the footer display
		unsetGetRequestElement('frame');
	}

	// Load header
	loadIncludeOnce('inc/header.php');

	// Determine template name
	$templateName = SURFBAR_DETERMINE_TEMPLATE_NAME();

	// Load that template
	//* DEBUG: */ die('templateName=' . $templateName . '<br /><strong>content</strong>=<pre>' . print_r($content, true) . '</pre>');
	loadTemplate($templateName, false, $content);
}

// Load footer
$GLOBALS['footer_sent'] = 3;
loadIncludeOnce('inc/footer.php');

// [EOF]
?>
